summaryrefslogtreecommitdiffstats
path: root/doc
diff options
context:
space:
mode:
authorThiago Macieira <thiago.macieira@nokia.com>2009-08-27 15:19:28 (GMT)
committerThiago Macieira <thiago.macieira@nokia.com>2009-08-27 15:19:28 (GMT)
commit162892030766ffe8711888ea9e8d3a368c6a75b2 (patch)
treeddfda2e163fdce5d7ead7ac1fbd7aedb4bb06b79 /doc
parent0bc91ae61b07751f44210e1b772679c0a180c900 (diff)
parent26b8b6783afe2c1c9f27c935eb46c05229757af1 (diff)
downloadQt-162892030766ffe8711888ea9e8d3a368c6a75b2.zip
Qt-162892030766ffe8711888ea9e8d3a368c6a75b2.tar.gz
Qt-162892030766ffe8711888ea9e8d3a368c6a75b2.tar.bz2
Merge branch '4.6'
Conflicts: src/opengl/gl2paintengineex/qpaintengineex_opengl2.cpp
Diffstat (limited to 'doc')
-rw-r--r--doc/src/examples/overpainting.qdoc7
-rw-r--r--doc/src/frameworks-technologies/graphicsview.qdoc20
-rw-r--r--doc/src/images/graphicseffect-blur.pngbin0 -> 41433 bytes
-rw-r--r--doc/src/images/graphicseffect-colorize.pngbin0 -> 35062 bytes
-rw-r--r--doc/src/images/graphicseffect-drop-shadow.pngbin0 -> 38770 bytes
-rw-r--r--doc/src/images/graphicseffect-effects.pngbin0 -> 112462 bytes
-rw-r--r--doc/src/images/graphicseffect-grayscale.pngbin0 -> 35056 bytes
-rw-r--r--doc/src/images/graphicseffect-opacity.pngbin0 -> 33879 bytes
-rw-r--r--doc/src/images/graphicseffect-pixelize.pngbin0 -> 23577 bytes
-rw-r--r--doc/src/images/graphicseffect-widget.pngbin0 -> 16693 bytes
-rw-r--r--doc/src/platforms/emb-displaymanagement.qdoc2
-rw-r--r--doc/src/snippets/animation/sequential/tracer.h41
-rw-r--r--doc/src/snippets/code/src_corelib_kernel_qobject.cpp6
-rw-r--r--doc/src/snippets/signalmapper/filereader.h41
14 files changed, 110 insertions, 7 deletions
diff --git a/doc/src/examples/overpainting.qdoc b/doc/src/examples/overpainting.qdoc
index 91100c0..b19b503 100644
--- a/doc/src/examples/overpainting.qdoc
+++ b/doc/src/examples/overpainting.qdoc
@@ -159,9 +159,10 @@
\snippet examples/opengl/overpainting/glwidget.cpp 7
- Once the list containing the object has been executed, the matrix stack
- needs to be restored to its original state at the start of this function
- before we can begin overpainting:
+ Once the list containing the object has been executed, the GL
+ states we changed and the matrix stack needs to be restored to its
+ original state at the start of this function before we can begin
+ overpainting:
\snippet examples/opengl/overpainting/glwidget.cpp 8
diff --git a/doc/src/frameworks-technologies/graphicsview.qdoc b/doc/src/frameworks-technologies/graphicsview.qdoc
index 8d7ea2c..397cb19 100644
--- a/doc/src/frameworks-technologies/graphicsview.qdoc
+++ b/doc/src/frameworks-technologies/graphicsview.qdoc
@@ -551,4 +551,24 @@
the widget is transformed resolution independently, allowing the
fonts and style to stay crisp when zoomed in. (Note that the effect
of resolution independence depends on the style.)
+
+ \section1 Performance
+
+ \section2 Floating Point Instructions
+
+ In order to accurately and quickly apply transformations and effects to
+ items, Graphics View is built with the assumption that the user's hardware
+ is able to provide reasonable performance for floating point instructions.
+
+ Many workstations and desktop computers are equipped with suitable hardware
+ to accelerate this kind of computation, but some embedded devices may only
+ provide libraries to handle mathematical operations or emulate floating
+ point instructions in software.
+
+ As a result, certain kinds of effects may be slower than expected on certain
+ devices. It may be possible to compensate for this performance hit by making
+ optimizations in other areas; for example, by using \l{#OpenGL Rendering}{OpenGL}
+ to render a scene. However, any such optimizations may themselves cause a
+ reduction in performance if they also rely on the presence of floating point
+ hardware.
*/
diff --git a/doc/src/images/graphicseffect-blur.png b/doc/src/images/graphicseffect-blur.png
new file mode 100644
index 0000000..3fa403b
--- /dev/null
+++ b/doc/src/images/graphicseffect-blur.png
Binary files differ
diff --git a/doc/src/images/graphicseffect-colorize.png b/doc/src/images/graphicseffect-colorize.png
new file mode 100644
index 0000000..96fbfe4
--- /dev/null
+++ b/doc/src/images/graphicseffect-colorize.png
Binary files differ
diff --git a/doc/src/images/graphicseffect-drop-shadow.png b/doc/src/images/graphicseffect-drop-shadow.png
new file mode 100644
index 0000000..c02415a
--- /dev/null
+++ b/doc/src/images/graphicseffect-drop-shadow.png
Binary files differ
diff --git a/doc/src/images/graphicseffect-effects.png b/doc/src/images/graphicseffect-effects.png
new file mode 100644
index 0000000..422ae19
--- /dev/null
+++ b/doc/src/images/graphicseffect-effects.png
Binary files differ
diff --git a/doc/src/images/graphicseffect-grayscale.png b/doc/src/images/graphicseffect-grayscale.png
new file mode 100644
index 0000000..2bd0c93
--- /dev/null
+++ b/doc/src/images/graphicseffect-grayscale.png
Binary files differ
diff --git a/doc/src/images/graphicseffect-opacity.png b/doc/src/images/graphicseffect-opacity.png
new file mode 100644
index 0000000..de15859
--- /dev/null
+++ b/doc/src/images/graphicseffect-opacity.png
Binary files differ
diff --git a/doc/src/images/graphicseffect-pixelize.png b/doc/src/images/graphicseffect-pixelize.png
new file mode 100644
index 0000000..047c452
--- /dev/null
+++ b/doc/src/images/graphicseffect-pixelize.png
Binary files differ
diff --git a/doc/src/images/graphicseffect-widget.png b/doc/src/images/graphicseffect-widget.png
new file mode 100644
index 0000000..27245d1
--- /dev/null
+++ b/doc/src/images/graphicseffect-widget.png
Binary files differ
diff --git a/doc/src/platforms/emb-displaymanagement.qdoc b/doc/src/platforms/emb-displaymanagement.qdoc
index 8a743b1..05267c1 100644
--- a/doc/src/platforms/emb-displaymanagement.qdoc
+++ b/doc/src/platforms/emb-displaymanagement.qdoc
@@ -152,7 +152,7 @@
\row
\o \c offset=<x,y>
\o Multi
- \o Specifies the coordinates of a subscreens top-left corner
+ \o Specifies the coordinates of a subscreen's top-left corner
(by default 0,0).
\endtable
diff --git a/doc/src/snippets/animation/sequential/tracer.h b/doc/src/snippets/animation/sequential/tracer.h
index 1adb018..ff3b089 100644
--- a/doc/src/snippets/animation/sequential/tracer.h
+++ b/doc/src/snippets/animation/sequential/tracer.h
@@ -1,3 +1,44 @@
+/****************************************************************************
+**
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Nokia Corporation (qt-info@nokia.com)
+**
+** This file is part of the documentation of the Qt Toolkit.
+**
+** $QT_BEGIN_LICENSE:LGPL$
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the either Technology Preview License Agreement or the
+** Beta Release License Agreement.
+**
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+**
+** In addition, as a special exception, Nokia gives you certain
+** additional rights. These rights are described in the Nokia Qt LGPL
+** Exception version 1.0, included in the file LGPL_EXCEPTION.txt in this
+** package.
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
+**
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at http://qt.nokia.com/contact.
+** $QT_END_LICENSE$
+**
+****************************************************************************/
+
#ifndef TRACER_H
#define TRACER_H
diff --git a/doc/src/snippets/signalmapper/filereader.h b/doc/src/snippets/signalmapper/filereader.h
index a3be088..d8ceb2e 100644
--- a/doc/src/snippets/signalmapper/filereader.h
+++ b/doc/src/snippets/signalmapper/filereader.h
@@ -1,3 +1,44 @@
+/****************************************************************************
+**
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Nokia Corporation (qt-info@nokia.com)
+**
+** This file is part of the documentation of the Qt Toolkit.
+**
+** $QT_BEGIN_LICENSE:LGPL$
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the either Technology Preview License Agreement or the
+** Beta Release License Agreement.
+**
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+**
+** In addition, as a special exception, Nokia gives you certain
+** additional rights. These rights are described in the Nokia Qt LGPL
+** Exception version 1.0, included in the file LGPL_EXCEPTION.txt in this
+** package.
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
+**
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at http://qt.nokia.com/contact.
+** $QT_END_LICENSE$
+**
+****************************************************************************/
+
#ifndef FILEREADER_H
#define FILEREADER_H
diff --git a/doc/src/snippets/code/src_corelib_kernel_qobject.cpp b/doc/src/snippets/code/src_corelib_kernel_qobject.cpp
index 5c0f80c..a02d4e9 100644
--- a/doc/src/snippets/code/src_corelib_kernel_qobject.cpp
+++ b/doc/src/snippets/code/src_corelib_kernel_qobject.cpp
@@ -39,10 +39,10 @@ timer->inherits("QTimer"); // returns true
timer->inherits("QObject"); // returns true
timer->inherits("QAbstractButton"); // returns false
-// QLayout inherits QObject and QLayoutItem
-QLayout *layout = new QLayout;
+// QVBoxLayout inherits QObject and QLayoutItem
+QVBoxLayout *layout = new QVBoxLayout;
layout->inherits("QObject"); // returns true
-layout->inherits("QLayoutItem"); // returns false
+layout->inherits("QLayoutItem"); // returns true (even though QLayoutItem is not a QObject)
//! [4]